This function performs the iterative clustering algorithm on the archaeological time series data. Detailed description can be found in Chazin et al. 2019, Supplemental Materials 1.
Arguments
- paths
A list of data frames, where each frame contains the data for one individual. There should be two columns with names 'distance' and 'oxygen'.
- bandwidth
Denotes the order of the bandwidth that should be used in the splitting-coalescence (SC) clustering algorithm. A value k will mean that the bandwidth used in the algorithm is n^k.
Value
A list of vectors where each vector gives the indexes of the individuals to be assigned in the same cluster.
Examples
if (FALSE) { # \dontrun{
armenia_split = split(armenia,f = armenia$ID)
band = -0.33
results = SCalgo(armenia_split,bandwidth = band)
} # }