Iteration step for the Splitting-Coalescence-Estimation Method (SCEM).
Source:R/iteration.R
iteration.RdThis function performs the iteration step. Detailed description can be found in Chazin et al. 2019, Supplemental Materials 1.
Arguments
- paths
A list of data frames, where each frame contains the data for one individual. Every data frame should have two columns with names 'distance' and 'oxygen'.
- U
A list of vectors. Each element in the list is a vector of integers, corresponding to individuals considered in one group.
- bandwidth
Denotes the order of the bandwidth that should be used in the estimation process. bandwidth = k will mean that the bandwidth is n^k.