Performs the updated nonlinear least squares (NLS) regression method for the cosine model (see Chazin et al. 2019).
Value
A fitted model object from the nls function in R:
- m
an 'nlsModel' object incorporating the model.
- convInfo
a list with convergence information
- data
the expression that was passed to 'nls' as the data argument. The actual data values are present in the environment of the 'm' component.
- call
the matched call with several components, notably 'algorithm'
- dataClasses
the '"dataClasses"' attribute (if any) of the '"terms"' attribute of the model frame.
- control
the control 'list' used
References
Florent Baty, Christian Ritz, Sandrine Charles, Martin Brutsche, Jean-Pierre Flandrois, Marie-Laure Delignette-Muller (2015). A Toolbox for Nonlinear Regression in R: The Package nlstools. Journal of Statistical Software, 66(5), 1-21. URL http://www.jstatsoft.org/v66/i05/.
Examples
armenia_split = split(armenia,f = armenia$ID)
sine_OLS(armenia_split[[1]])
#> Nonlinear regression model
#> model: oxygen ~ intercept + amplitude * cos(frequency * distance + phase)
#> data: data
#> intercept amplitude phase frequency
#> -4.2485 5.2653 0.7701 0.1657
#> residual sum-of-squares: 1.371
#>
#> Number of iterations to convergence: 6
#> Achieved convergence tolerance: 2.068e-06