Cosine model fitting with given initialization for two parameters.
Source:R/sine_initial.R
sine_initial.RdPerforms the updated nonlinear least squares (NLS) regression method for the cosine model proposed by Balasse et al. The method calculates with the proposed initial values for ampliitude and intercept, and then fits the NLS method as required.
Value
A fitted model object from the nls function in R:
- m
an 'nlsModel' object incorporating the model.
- convInfo
a list with convergence information
- data
the expression that was passed to 'nls' as the data argument. The actual data values are present in the environment of the 'm' component.
- call
the matched call with several components, notably 'algorithm'
- dataClasses
the '"dataClasses"' attribute (if any) of the '"terms"' attribute of the model frame.
- control
the control 'list' used
References
Florent Baty, Christian Ritz, Sandrine Charles, Martin Brutsche, Jean-Pierre Flandrois, Marie-Laure Delignette-Muller (2015). A Toolbox for Nonlinear Regression in R: The Package nlstools. Journal of Statistical Software, 66(5), 1-21. URL http://www.jstatsoft.org/v66/i05/.
Examples
armenia_split = split(armenia,f = armenia$ID)
amp = seq(1,10,by=0.5)
int = seq(-25,0,by=0.5)
sine_initial(armenia_split[[2]],amp[3],int[4])
#> Nonlinear regression model
#> model: oxygen ~ intercept + amplitude * cos(frequency * distance + phase)
#> data: data
#> intercept amplitude phase frequency
#> -5.7143 5.9191 -0.1394 0.1776
#> residual sum-of-squares: 1.049
#>
#> Number of iterations to convergence: 8
#> Achieved convergence tolerance: 1.249e-06